PyTest - pypackitup - Python Package Template
Author: Wren J. Rudolph for Wrencode, LLC

# `PyTest`

Modules:

Name | Description
--- | ---
`conftest` | Pytest top-level conftest.py.
`test_helloworld` | Pytest test for Python Package Template code.

## conftest

Pytest top-level conftest.py.

Functions:

Name | Description
--- | ---
`python_package_template` | Create a PythonPackageTemplate class object for testing.

### python_package_template

    python_package_template()

Create a PythonPackageTemplate class object for testing.

Returns: | `PythonPackageTemplate`( `PythonPackageTemplate` ) – Python package template class instance.

Source code in `tests/conftest.py`

    12
    13
    14
    15
    16
    17
    18
    19
    20
    @pytest.fixture(scope="module")
    def python_package_template() -> PythonPackageTemplate:
        """Create a PythonPackageTemplate class object for testing.

        Returns:
            PythonPackageTemplate: Python package template class instance.

        """
        return PythonPackageTemplate()

## test_helloworld

Pytest test for Python Package Template code.

Note

Tests helloworld.py module.

GitHub « Previous